LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.std_logic_unsigned.all;
USE ieee.std_logic_arith.ALL;
 
ENTITY tb_aram IS
END tb_aram;
 
ARCHITECTURE behavior OF tb_aram IS 
 
    -- Component Declaration for the Unit Under Test (UUT)
 
    COMPONENT asynch_ram_module
    Port ( wr_i	: in std_logic; --wr='1' set ram in write mode, wr='0' set ram in read mode
			  oe_i   : in std_logic; -- output enable input
			  addr_i : in  STD_LOGIC_VECTOR (4 downto 0);
           data_io : inout  STD_LOGIC_VECTOR (7 downto 0));
    END COMPONENT;
    

   --Inputs
   signal wr_i : std_logic := '0';
	signal oe_i : std_logic := '0';
   signal addr_i : std_logic_vector(4 downto 0) := (others => '0');

	--BiDirs
   signal data_io : std_logic_vector(7 downto 0);


	constant period : time:= 10ns; 

 
BEGIN
 
	-- Instantiate the Unit Under Test (UUT)
   uut: asynch_ram_module PORT MAP (
          wr_i => wr_i,
			 oe_i => oe_i,
          addr_i => addr_i,
          data_io => data_io
        );
 
   -- Stimulus process
	process
	begin
		-- writing into first 16 positions
		data_io <= x"00";
		wr_i<='0';
		oe_i<='0';
		for I in 0 to 16 loop
			data_io <=  conv_std_logic_vector(I,8);
			wait for period/4; 
			wr_i<='1';
			wait for period/4; 
			wr_i<='0';
			wait for period/4; 
			addr_i<=addr_i+1;
			wait for period/4; 
		end loop;
		data_io<=(others => 'Z');
		-- reading all addresses
		wr_i<='0';
		oe_i<='1';
		addr_i<=(others=>'0');
		wait for period;
		for I in 0 to 31 loop
			wait for period; 
			addr_i<=addr_i+1;
		end loop;
		
	end process;
 

END;
