library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;


entity tb_sram is
end tb_sram;

architecture Behavioral of tb_sram is
component synch_ram_module is
    Port ( clk_i	: in std_logic;
			  wr_i	: in std_logic; --wr='1' set ram in write mode, wr='0' set ram in read mode
			  oe_i   : in std_logic; -- output enable input
			  addr_i : in  STD_LOGIC_VECTOR (4 downto 0);
           data_io : inout  STD_LOGIC_VECTOR (7 downto 0));
end component;
   

   --Inputs
	signal clk_i : std_logic := '0';   
	signal wr_i : std_logic := '0';
	signal oe_i : std_logic := '0';
   signal addr_i : std_logic_vector(4 downto 0) := (others => '0');

	--BiDirs
   signal data_io : std_logic_vector(7 downto 0);


	constant period : time:= 10ns; 

begin
   uut: synch_ram_module PORT MAP (
          clk_i => clk_i,
			 wr_i => wr_i,
			 oe_i => oe_i,
          addr_i => addr_i,
          data_io => data_io
        );

clk_i<= not clk_i after period/2;

   -- Stimulus process
	process
	begin
		-- writing into first 16 positions
		data_io <= x"00";
		wr_i<='0';
		oe_i<='0';
		for I in 0 to 16 loop
			data_io <=  conv_std_logic_vector(I,8);
			wait until clk_i='0';
			wr_i<='1';
			wait until clk_i='0'; 
			wr_i<='0';
			wait until clk_i='0'; 
			addr_i<=addr_i+1;
			wait until clk_i='0'; 
		end loop;
		data_io<=(others => 'Z');
		-- reading all addresses
		wr_i<='0';
		oe_i<='1';
		addr_i<=(others=>'0');
		wait until clk_i='1';
		for I in 0 to 31 loop
			wait until clk_i='0'; 
			addr_i<=addr_i+1;
		end loop;
		
	end process;


end Behavioral;

